;; Generated package description from consult-denote.el  -*- no-byte-compile: t -*-
(define-package "consult-denote" "0.1.2" "Use Consult in tandem with Denote" '((emacs "28.1") (denote "3.0.3") (consult "1.7")) :commit "78d9cdff11554bdca8183091b59bc8c759f66d1c" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/consult-denote")
